Welcome to aiothrift
====================

asyncio (:pep:`3156`) Thrift client and server library.


Installation
------------

The easiest way to install aiothrift is by using the packae on Pypi::

    pip install aiothrift

Requirements
-------------

- Python 3.4 +

Contribute
----------

- Issue Tracker: https://github.com/moonshadow/aiothrift/issues
- Source Code: https://github.com/moonshadow/aiothrift

Feel free to file an issue or make pull request if you find any bugs or have
some suggestions for library improvement.

----

User's Guide
============


.. toctree::
   :maxdepth: 2

   quickstart
   examples

API Reference
-------------

If you are looking for information on a specific function, class or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api

.. _MIT license: https://github.com/moonshadow/aiothrift/blob/master/LICENSE


Additional Notes
----------------

Information and changelog are here for the interested.

.. toctree::
    :maxdepth: 1

    license
    CHANGES<changelog>